% Baccala & Sameshima. Partial directed coherence: a new concept in neural
% structure determination. Biol. Cybern. 84:463-474, 2001.
%                http://dx.doi.org/10.1007/PL00007990
% Example 3 (pag.468)
%                       VAR(3) with loop and feedback

clear; clc
N=10000;
%%=>review
disp('======================================================================');
disp('               Linear 2-dimensional VAR[2] Model')
disp(' Baccala & Sameshima. CRC Book example 1 PDC - 10000:1 error variances ')
disp('                    Original PDC Euclidean Metric                     ');
disp('             x1-->x2                                                  ')
disp('======================================================================');

randn('state', 2.067392000000000e+005)
ei=randn(2,N);
% generation of different variances 
ei=[100 0;0 1]*ei;
%
x1=zeros(1,N);
x2=zeros(1,N);
% Variables initialization
for t=1:4,
   x1(t)=randn(1); x2(t)=randn(1); 
end;

chLabels = {'x_1';'x_2'}; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};


for t=5:N,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + ei(1,t);
   x2(t) =-.5*x2(t-1)+ 0.5*x1(t-1) + ei(2,t);
   %x3(t) = -0.4*x1(t-3) + ei(3,t);
   %x4(t) = -0.5*x1(t-2) + 0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-1) + ei(4,t);
   %x5(t) = -0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-1) + ei(5,t);
end;

nDiscard=1000; % number of points discarded at beginning of series
nPoints=200;   % number of analyzed samples points

y=[x1' x2'];% x3' x4' x5']; % data must be organized column-wise

u=y(nDiscard+1:nDiscard+nPoints,:);

%==========================================================================
%                     PDCn estimation and analysis parameters
%==========================================================================


run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [1 0 0 0 0 0 1]; % overriding default setting
% alpha=0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level
% flgColor = 0;
metric = 'euc';

run example_pdc_analysis        % Estimate PDC and asymptotic statistics

%save baccala2001a_ex3_PDC

flgColor = 0;
%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;

strTitle1 = ['2-dimensional linear VAR[2] Model: '];
strTitle2 = ['[N=' int2str(nSegLength) 'pts; IP=' int2str(c.p) '; ' ...
   datestr(now) ']'];
strTitle =[strTitle1 strTitle2];

for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
         'Name', 'Original PDC')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                             flgScale,flgMax,flgSignifColor);
   xplot_title(alpha,metric);
   [ax,hT]=suplabel( strTitle, 't' );
   set(hT,'FontSize',8) 
end;

% disp('')
% disp('==> Check & compare Fig. 2b, page 468, Baccala & Sameshima (2001).')
% disp(' ')
% disp('==> Note that in the original article the amplitude PDC has been plotted.')
% disp('    Here we preferred to graph squared-PDC.')
% disp(' ')
% disp('======================================================================');
% disp('      This completes the Example 3 (Baccal & Sameshima, 2001)');
% disp('======================================================================');
