clear; clc; format compact

% Data File: skin.dat
% This data is from Andrews and Herzberg.
% The aetiology of melanoma is complex and may include the influences
% of trauma, heredity and hormonal activity. In particular, exposure
% to solar radiation may be involved in the pathogenesis of melanoma.
% Melanoma is more common in fair-skinned individuals and most frequent
% in skin sites exposed to the sun. In white populations melanoma is
% more common in areas closer to the equator where the intensity of
% solar radiation is higher. Data from various parts of the world suggest
% that the incidence of melanoma is increasing. The data below, giving
% age-adjusted melanoma incidence, are from the Connecticut Tumor Registry
% from 1936-1972. Connecticut has the longest record of state
% population-based cancer statistics in the United States of America.
% The data also includes the sunspot relative number. Houghton, Munster
% and Viola (1978) have shown that the age-adjusted incidence rate for
% malignant melanoma in the state of Connecticut has risen since 1935 and
% that superimposed on the rise are 3-5 year periods in which the rise
% in the rate of incidence is excessive. These periods have a cycle of
% 8-11 years and follow times of maximum sunspot activity. The relationship
% between solar cycles and melanoma supports the hypothesis that melanoma
% is related to sun exposure and provides evidence that solar radiation
% may trigger the development of clinically apparent melanoma. The columns
% are the year, male incidence, total incidence, and sunspot relative
% index. The incidence are rates per 100,000.
%
% Below is the contents of the file skin.dat:
% Year % 1936-1972
% ANNUAL MALE MELANOMA INCIDENCE(AGE-ADJUSTED PER 10**5) CONNECTICUT
% ANNUAL TOTAL MELANOMA INCIDENCE(AGE-ADJUSTED PER 10**5) CONNECTICUT
% ANNUAL SUNSPOT RELATIVE NUMBER

%============= Causality Analysis using PDC ==============================
% In this example, ANNUAL SUNSPOT RELATIVE NUMBER and TOTAL MELANOMA
% INCIDENCE(AGE-ADJUSTED PER 10**5) in the state of CONNECTICUT will be
% considered

disp('======================================================================');
disp('     Andrews and Herzberg''s Sunspot and Melanoma 1936-1972 Data');
disp('                 Sunspot --> Melanoma or other way?');
disp('======================================================================');

flgDataPlot = 2; %for Figure 4.8 plotting use 2.

% Data set for analysis

x=sunmeladat([4 3]); chLabels={'Sunspot';'Melanoma'};
u = x;
nPoints = length(u);
if flgDataPlot,
   year=sunmeladat(1);  % Year variable
   h1=figure;
   set(h1,'NumberTitle','off','MenuBar','none', ...
      'Name','Figure 4.7 - Andrews & Herzberg''s Sunspot-Melanoma Series (1936-1972)')
   h = subplot(311); plot(year,u(:,1),'o:r');
   title('Annual sunspot number'); grid
   set(h,'XLim', [1935 1975], ...             %'YLim',ylim, ...
      'XTick',[1935:5:1975], ...
      'XTickLabel',[' ';' ';' ';' ';' ';' ';' ';' ';' ']);

   h = subplot(312); plot(year,u(:,2),'.:'); xlabel('');
   title('Annual total melanoma incidence rates per 100,000 in the state of Connecticut');
   grid
   set(h,'XLim', [1935 1975], ...             %'YLim',ylim, ...
      'XTick',[1935:5:1975], ...
      'XTickLabel',[' ';' ';' ';' ';' ';' ';' ';' ';' ']);
   h = subplot(313); plot(year,detrend(u(:,2)),'.:'); xlabel('year');
   set(h,'XLim', [1935 1975])
   title('Detrended melanoma series')
   grid; hold on; pause(1)

   h2=figure;
   set(h2,'NumberTitle','off','MenuBar','none', ...
      'Name','Figure 4.8 - Andrews & Herzberg''s Sunspot-Melanoma Series (1936-1972)')
      u2=u(:,2); u2=detrend(u2);
   if flgDataPlot ~= 2,
      h = subplot(211); plot(year,(u2-mean(u2))/std(u2),'b*:',...
         year,(u(:,1)-mean(u(:,1)))/std(u(:,1)),'ro-');
      set(h,'XLim', [1935 1975])
      title('Melanoma & Sunspot: Standardized series')
      legend('Melanoma','Sunspot'); xlabel('year'); grid
   end;

   [uxcorr,lag]=xcorr(u2,u(:,1),'coeff');
   subplot(212); plot(lag,uxcorr,'o--'); xlabel('lag(year)');
   title('Normalized cross-correlation function'); axis([-20 20 -1 1]); grid; hold on
   %tilefigs
end;
