% Baccala & Sameshima. Baccala & Sameshima.
%       CRC Book example 1 PDC - equal
%            error variances - euclidean metric

clear; clc; format compact; format short

ndiscard = 1000;
ns = 200;

disp('======================================================================');
disp('               Linear 2-dimensional VAR[2] Model')
disp(' Baccala & Sameshima. CRC Book Example 4.1 PDC - equal error variances ')
disp('             x1-->x2                                                  ')
disp('======================================================================');

nd = ns + ndiscard;

randn('state', 2.067392000000000e+005)
ei=randn(2,nd);
x1=zeros(1,nd);
x2=zeros(1,nd);
% Variables initialization
for t=1:4,
   x1(t)=randn(1); x2(t)=randn(1); 
end;

chLabels = {'x_1';'x_2'}; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};


for t=5:nd,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + ei(1,t);
   x2(t) = -.5*x2(t-2)+ 0.5*x1(t-1) + ei(2,t);
end;

nDiscard=1000; % number of points discarded at beginning of series
nPoints=200;   % number of analyzed samples points

y=[x1' x2'];%  data must be organized column-wise

u = y(nd - ns + 1:nd,:);

%==========================================================================
%                     PDCn estimation and analysis parameters
%==========================================================================


run example_analysis_parameters % Setting default paramaters

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [1 0 0 0 0 0 1]; % overriding default setting
alpha=0;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level
% flgColor = 0;
metric = 'euc';

run example_pdc_analysis        % Estimate PDC and asymptotic statistics

%save baccala2001a_ex3_PDC

flgColor = 0;
%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;

strTitle1 = ['2-dimensional linear VAR[2] Model: '];
strTitle2 = ['[nd=' int2str(nSegLength) 'pts; IP=' int2str(c.p) '; ' ...
   datestr(now) ']'];
strTitle =[strTitle1 strTitle2];

for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
         'Name', 'Figure 4.3 PDC in standard form')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);
   xplot_title(alpha,metric);
   [ax,hT]=suplabel( strTitle, 't' );
   set(hT,'FontSize',8) 
end;
