clear; clc

disp('======================================================================');
disp('        Example 7.2 Closed and almost unstable loop')
disp('           x1 ->x2  x2->x3 x3->x1                   ');
disp('======================================================================');


ndiscard=40000; % number of points discarded at beginning of series
ns=2000;   % number of analyzed samples points
nd = ndiscard + ns;

h0=sum(100*clock)
randn('state', h0)
SZ=[1 5 .30; 5 100 2; .30 2 1]; SZ=chol(SZ);
wi = randn(3,nd); wi = SZ'*wi;
x1 = zeros(1,nd); x2 = zeros(1,nd); x3 = zeros(1,nd);
 
% Variables initialization
for t=1:2,
   x1(t) = randn(1); x2(t) = randn(1); x3(t) = randn(1);
end;

chLabels = []; % or %chLabels = {'x_1';'x_2';'x_3'};

for t=3:nd,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + 0.35*x3(t-1) + wi(1,t);
   x2(t) = .5*x1(t-1) + .5*x2(t-1) + wi(2,t);
   x3(t) = -.5*x3(t-1) + x2(t-1) + wi(3,t);
end;

y = [x1' x2' x3']; % data must be organized column-wise

u = y(nd - ns + 1:nd, :)';
%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [1 1 1 2 2 0 1]; % overriding xplot default setting
%                    | | | +----> plotting power spectra in linear scale
%                    | | +------> w/o coherence, and using
%                    +-+--------> shading for |PDC|^2 95% confidence interval
alpha = 0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level
metric = 'info';

run example_pdc_analysis

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;

flgColor = 1;
flgScale = 2;
flgMax = 'TCI';
flgSignifColor = 1;

for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
         'Name', 'Figure 7.2 Oscillator with closed-loop')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);
   [ax,hT]=suplabel(['Oscillator loop: ' ...
      int2str(ns) ' data points.'],'t');
   set(hT,'FontSize',12); % Title font size
   xplot_title(alpha,metric);
end;

disp('======================================================================');
disp('      This completes  Example 7.2 -- Loop Oscillator');
disp('======================================================================');
