%
% Baccala & Sameshima. Balanced Notch Filter - zero midband transmission
% 
% 

clear; clc
N=100000;
disp('======================================================================');
disp('                         Midband Notch Model                          ')
%disp('         Baccala & Sameshima. Biol. Cybern. 84:463-474, 2001.')
%disp('           x1==>x2  x1-->x3 x1-->x4 x4-->x5 x5-->x4 x5-->x1');
disp('======================================================================');

randn('state', sum(100*clock))
% Balanced innovations input
SZ=[100 0.5 ;0.5 1]; SZ=chol(SZ);
wi=randn(2,N); wi=SZ'*wi;
x1=zeros(1,N); x2=zeros(1,N);

% Variables initialization
for t=1:3,
   x1(t)=randn(1); x2(t)=randn(1);%
end;

chLabels = []; % or  %chLabels = {'x_1';'x_2'};

for t=4:N,
   x1(t) = .5*x1(t-1) + wi(1,t);
   x2(t) = -.5*x2(t-1) + x1(t-1) + x1(t-3) + wi(2,t);
end;

nDiscard=40000; % number of points discarded at beginning of series (sem efeito)
nPoints=1000;   % number of analyzed samples points

y=[x1' x2']; % data must be organized column-wise

u=y(N-nPoints+1:N,:);%size(u),pause

%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 
nFreqs=1024;

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [2 1 1 2 2 0 0]; % overriding default setting

alpha=0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level
metric = 'euc';
run example_pdc_analysis

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
flgColor = 0;   
flgSignifColor = 3;
for kflgColor = flgColor,
   h=figure;
    set(h,'NumberTitle','off','MenuBar','none', ...
          'Name', 'Figure 7.4(a) PDC Midband Notch')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);

   [ax,hT]=suplabel(['Unbalanced notch: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',10); % Title font size
   xplot_title(alpha,metric);
end;

%==========================================================================
%             Information PDCn estimation and analysis parameters
%==========================================================================

metric = 'info';
run example_pdc_analysis

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
   
for kflgColor = flgColor,
   h=figure;
    set(h,'NumberTitle','off','MenuBar','none', ...
          'Name', 'Figure 7.4(b) iPDC Midband Notch')
   [hxlabel hylabel] = xplot(c,flgPrinting,fs,w_max,chLabels,kflgColor, ...
                                              flgScale,flgMax,flgSignifColor);
   [ax,hT]=suplabel(['Unbalanced notch: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',10); % Title font size
   xplot_title(alpha,metric);
end;
