% Eichler. On the evaluation of information flow in multivariate systems 
% by the directed transfer function.
%            Biol Cybern (2006) 94: 469?482
%           [http://dx.plos.org/10.1007/s00422-006-0062-z] 
% 
%  Example - two-dimensional VAR[2].

clc; format compact
N=60000;
disp('======================================================================');
disp('                   Three dimensional linear VAR[2] Model')
disp('                           Eichler, 2006.')
disp('                      x1-->x2  x2-->x1 x2-->x3 ');
disp('======================================================================');
if ~exist('flgManual','var')
   flgManual = 0
end;

if flgManual
   if exist('randn_manual_state.mat','file'),
      load randn_manual_state
      randn('state', s);
      disp(['Using state saved in "randn_manual_state.mat" to reproduce figure in the manual.']);
   else
      disp(['Did not find "randn_manual_state.mat" file.' ...
         'Assigned "sum(100*clock)" initial state.']);
      randn('state', sum(100*clock))
   end;
else
   randn('state', sum(100*clock))
   disp('Assigned "sum(100*clock)" initial state.2')
end;
% Variables initialization
e=randn(3,N);
x1=zeros(1,N);
x2=zeros(1,N);
x3=zeros(1,N);

disp('======================================================================');

for t=1:3,
   x1(t)=randn(1); x2(t)=randn(1); x3(t)=randn(1);
end;

chLabels = {'x_1';'x_2';'x_3'}; %or %chLabels = []; 

for t=4:N,
   x1(t) = 4/15*x1(t-1) - (1./4.)*x1(t-2) + .4*x2(t-1) - .2*x2(t-2) + e(1,t);
   x2(t) = 0.4*x1(t-1) + 0.2*x1(t-2) + (5./28.)*x2(t-1) - (1./9.)*x2(t-2) + e(2,t);
   x3(t) = .4*x2(t-1) + .2*x2(t-2) + (5./28.)*x3(t-1) - (1./9.)*x3(t-2) + e(3,t);

end;


nDiscard=5000;  % number of points discarded at beginning of series
nPoints=2000;   % number of analyzed samples points

y=[x1' x2' x3']; % data must be organized column-wise
u=y(nDiscard+1:nDiscard+nPoints,:);

[nSegLength,nChannels]=size(u);

%==========================================================================
%             original pdc estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.
criterion = 5;
maxIP = 4;
%=======Overriding some default parameters for plotting and analysis=======

metric = 'euc';
flgColor = 0;
flgPrinting = [1 1 1 1 1 0 2]; % overriding default setting

run example_pdc_analysis        % Estimate pdc and asymptotic statistics

%========================pdcn Matrix Layout Plotting=======================
w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   xplot_title(alpha,metric);
end;

%==========================================================================
%       DC analysis of Guo et al (2008) Common exogenous noise model
%==========================================================================

%=======Overriding some default parameters for plotting and analysis=======
flgPrinting = [1 1 1 1 1 0 2]; % overriding default setting
metric = 'diag';
flgColor = [0];

run example_pdc_analysis

%========================gpdc Matrix Layout Plotting=======================

w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = pdc_xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   pdc_xplot_title(alpha,metric);
end;

%==========================================================================
%                     ipdc analysis of the same process
%==========================================================================

%====Overriding default some parameters value for plotting andanalysis=====

flgPrinting = [1 1 1 1 1 0 2]; % overriding default setting

metric = 'info';
flgColor = [0 1];

run example_pdc_analysis


%========================ipdc Matrix Layout Plotting=======================
w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = pdc_xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   pdc_xplot_title(alpha,metric);
end;


disp(' ')
disp('======================================================================');
disp('             This completes Eichler et al. (2006) example.');
disp('======================================================================');
